pub struct Manager<I, B, M>{ /* private fields */ }Expand description
Manager to reconcile state between a network interface and a behavior
Implementations
Sourceimpl<I, B, M> Manager<I, B, M>
impl<I, B, M> Manager<I, B, M>
Sourcepub fn new(interface: I, behavior: B) -> Self
pub fn new(interface: I, behavior: B) -> Self
Creates a new manager from an interface and a behavior.