pub enum InterfaceEvent<M: Message> {
Connected(PeerId),
Disconnected(PeerId),
Sent(PeerId, M),
Recv(PeerId, Vec<M>),
Error(PeerId, InterfaceError),
Idle,
}Expand description
A low-level event from the network interface
Variants
Connected(PeerId)
A connection to the peer was successfully established.
Disconnected(PeerId)
The peer has been disconnected.
Sent(PeerId, M)
A message was successfully sent to the peer.
Recv(PeerId, Vec<M>)
One or more messages were received from the peer.
Error(PeerId, InterfaceError)
An error occurred on the connection to the peer.
Idle
No pending IO activity; useful for triggering housekeeping.